# Module Index

- `smartcard` - Smartcard utility module.
  - `AbstractCardRequest` - AbstractCardRequest class.
  - `ATR` - ATR class managing some of the Answer To Reset content.
  - `Card` - Card class.
  - `CardConnection` - The CardConnection abstract class manages connections with a card and apdu transmission.
  - `CardConnectionDecorator` - The CardConnectionDecorator is a Decorator around the CardConnection abstract class, and allows dynamic addition of features to the CardConnection, e.g. implementing a secure channel..
  - `CardConnectionEvent` - The CardConnectionEvent is sent to CardConnectionObserver objects when a CardConnection event occurs.
  - `CardConnectionObserver` - CardConnectionObserver interface.
  - `CardMonitoring` - Smart card insertion/removal monitoring classes.
  - `CardNames` - Card Names class
  - `CardRequest` - Smartcard CardRequest.
  - `CardService` - Card service abstract class.
  - `CardType` - Abstract CarType.
  - `ClassLoader` - ClassLoader allows you to load modules from packages without hard-coding their class names in code; instead, they might be specified in a configuration file, as command-line parameters, or within an interface.
  - `Exceptions` - Smartcard module exceptions.
  - `ExclusiveConnectCardConnection` - CardConnectionDecorator that provides exclusive use of a card.
  - `ExclusiveTransmitCardConnection` - Sample CardConnectionDecorator that provides exclusive transmit()
  - `guid` - smartcard.guid
  - `Observer` - from Thinking in Python, Bruce Eckel http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html
  - `PassThruCardService` - Card service abstract class.
  - `pcsc` - No package docstring; 7/7 modules documented
    - `PCSCCardConnection` - PCSCCardConnection class manages connections thru a PCSC reader.
    - `PCSCCardRequest` - PCSC Smartcard request.
    - `PCSCContext` - PCSC context singleton.
    - `PCSCExceptions` - Smartcard module exceptions.
    - `PCSCPart10` - PCSCPart10: PC/SC Part 10 (pinpad)
    - `PCSCReader` - PCSCReader: concrete reader class for PCSC Readers
    - `PCSCReaderGroups` - PCSCReaderGroups organizes smartcard readers as groups.
  - `pyro` - pyro (remote python) utility module.
    - `PyroReader` - PyroReaderClient: concrete reader class for Remote Readers
    - `server` - pyro server utility module.
      - `PyroDaemon` - PyroDaemon: Wrapper class around pyro daemon
      - `PyroEventServer` - Utility class to start/stop Pyro Event Server.
      - `PyroNameServer` - Utility class to start/stop Pyro Name Server.
      - `RemoteCardConnection` - RemoteCardConnection class manages connections to a remote reader thru pyro (http://www.xs4all.nl/~irmen/pyro3/).
      - `RemoteReaderServer` - RemoteReaderServer: monitor local readers and publish them as pyro Remote Readers.
  - `reader` - No package docstring; 3/3 modules documented
    - `Reader` - Smart card Reader abstract class.
    - `ReaderFactory` - ReaderFactory: creates smartcard readers.
    - `ReaderGroups` - ReaderGroups manages smart card reader in groups.
  - `ReaderMonitoring` - Smart card reader monitoring classes.
  - `scard` - No package docstring; 1/1 module documented
    - `scard` - The smartcard.scard module is a simple wrapper on top of the C language PCSC SCardXXX API.
  - `sw` - smartcard.sw module for status word error checking.
    - `ErrorChecker` - Base class for status word error checkers.
    - `ErrorCheckingChain` - The error checking chain is a list of status word (sw1, sw2) error check strategies.
    - `ISO7816_4_SW1ErrorChecker` - ISO7816-4 sw1 only error checker.
    - `ISO7816_4ErrorChecker` - ISO7816-4 error checking strategy.
    - `ISO7816_8ErrorChecker` - ISO7816-8 error checker.
    - `ISO7816_9ErrorChecker` - ISO7816-9 error checker.
    - `op21_ErrorChecker` - Open Platform 2.1 error checker.
    - `SWExceptions` - Status Word (SW) Exceptions
  - `Synchronization` - from Thinking in Python, Bruce Eckel http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html
  - `System` - Smartcard system utility functions and classes.
  - `ulist` - ulist is a subclass of list where items cannot appear twice in the list.
  - `util` - smartcard.util package
  - `wx` - wxpython smartcard utility module.
    - `APDUHexValidator` - A wxValidator that matches APDU in hexadecimal such as:
    - `APDUTracerPanel` - Graphical APDU Tracer.
    - `CardAndReaderTreePanel` - wxPython panel display cards/readers as a TreeCtrl.
    - `ReaderToolbar` - wxPython toolbar with reader icons implementing ReaderObserver.
    - `SimpleSCardApp` - Simple wxPython wxApp for smartcard.
    - `SimpleSCardAppEventObserver` - Smartcard event observer.
    - `SimpleSCardAppFrame` - Simple wxpython frame for smart card application.